# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_grpc.ipynb.

# %% auto 0
__all__ = ['TorchServeClientGRPC']

# %% ../nbs/02_grpc.ipynb 3
import os
import grpc
import torchserve_client.proto.inference_pb2 as inference_pb2
import torchserve_client.proto.inference_pb2_grpc as inference_pb2_grpc
import torchserve_client.proto.management_pb2 as management_pb2
import torchserve_client.proto.management_pb2_grpc as management_pb2_grpc

# %% ../nbs/02_grpc.ipynb 4
class BaseClient:
    def __init__(self, base_url=None):
        base_url = (
            base_url
            if base_url
            else os.environ.get("TORCHSERVE_URL", "http://localhost")
        )
        self.base_url = base_url.split("//")[1]

    def __repr__(self) -> str:
        return f"{self.__class__.__name__}(base_url={self.base_url})"

    def _filter_none_values(self, data):
        return {key: value for key, value in data.items() if value is not None}

# %% ../nbs/02_grpc.ipynb 5
class ManagementClient(BaseClient):
    def __init__(self, base_url=None, port=7071):
        super().__init__(base_url)
        self.port = port
        self.base_url = f"{self.base_url}:{self.port}"
        self.channel = grpc.insecure_channel(self.base_url)
        self.stub = management_pb2_grpc.ManagementAPIsServiceStub(self.channel)

    def describe_model(self, model_name, model_version=None, customized=None):
        method_args = {key: value for key, value in locals().items() if key != "self"}
        method_args = self._filter_none_values(method_args)
        request = management_pb2.DescribeModelRequest(model_name=model_name)
        return self.stub.DescribeModel(request)

    def list_models(self, limit=None, next_page_token=None):
        method_args = {key: value for key, value in locals().items() if key != "self"}
        method_args = self._filter_none_values(method_args)
        request = management_pb2.ListModelsRequest(**method_args)
        return self.stub.ListModels(request)

    def register_model(
        self,
        batch_size=None,
        handler=None,
        initial_workers=None,
        max_batch_delay=None,
        model_name=None,
        response_timeout=None,
        runtime=None,
        synchronous=None,
        url=None,
        s3_sse_kms=None,
    ):
        method_args = {key: value for key, value in locals().items() if key != "self"}
        method_args = self._filter_none_values(method_args)
        request = management_pb2.RegisterModelRequest(**method_args)
        return self.stub.RegisterModel(request)

    def scale_worker(
        self,
        model_name,
        min_worker=None,
        max_worker=None,
        model_version=None,
        number_gpu=None,
        synchronous=None,
        timeout=None,
    ):
        method_args = {key: value for key, value in locals().items() if key != "self"}
        method_args = self._filter_none_values(method_args)
        request = management_pb2.ScaleWorkerRequest(**method_args)
        return self.stub.ScaleWorker(request)

    def set_default(self, model_name, model_version):
        method_args = {key: value for key, value in locals().items() if key != "self"}
        method_args = self._filter_none_values(method_args)
        request = management_pb2.SetDefaultRequest(**method_args)
        return self.stub.SetDefault(request)

    def unregister_model(self, model_name, model_version=None):
        method_args = {key: value for key, value in locals().items() if key != "self"}
        method_args = self._filter_none_values(method_args)
        request = management_pb2.UnregisterModelRequest(**method_args)
        return self.stub.UnregisterModel(request)

# %% ../nbs/02_grpc.ipynb 6
class InferenceClient(BaseClient):
    def __init__(self, base_url=None, port=7070):
        super().__init__(base_url)
        self.port = port
        self.base_url = f"{self.base_url}:{self.port}"
        self.channel = grpc.insecure_channel(self.base_url)
        self.stub = inference_pb2_grpc.InferenceAPIsServiceStub(self.channel)

    def ping(self):
        return self.stub.Ping()

    def predictions(self, model_name, input_data, model_version=None):
        """
        input_data = {"data": data}
        """
        method_args = {key: value for key, value in locals().items() if key != "self"}
        method_args = self._filter_none_values(method_args)
        request = inference_pb2.PredictionsRequest(**method_args)
        return self.stub.Predictions(request)

    def stream_predictions(self, model_name, input_data, model_version=None):
        """
        input_data = {"data": data}
        """
        method_args = {key: value for key, value in locals().items() if key != "self"}
        method_args = self._filter_none_values(method_args)
        request = inference_pb2.PredictionsRequest(**method_args)
        return self.stub.StreamPredictions(request)

# %% ../nbs/02_grpc.ipynb 7
class TorchServeClientGRPC:
    def __init__(self, base_url=None, management_port=7071, inference_port=7070):
        self.management = ManagementClient(base_url, management_port)
        self.inference = InferenceClient(base_url, inference_port)

    def __repr__(self):
        url = self.management.base_url.rsplit(":", 1)[0]
        return f"TorchServeClientGRPC(base_url={url}, management_port={self.management.port}, inference_port={self.inference.port})"



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/torchserve_client',
                'doc_host': 'https://Ankur-singh.github.io',
                'git_url': 'https://github.com/Ankur-singh/torchserve_client',
                'lib_path': 'torchserve_client'},
  'syms': { 'torchserve_client.grpc': { 'torchserve_client.grpc.BaseClient': ('grpc.html#baseclient', 'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.BaseClient.__init__': ( 'grpc.html#baseclient.__init__',
                                                                                        'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.BaseClient.__repr__': ( 'grpc.html#baseclient.__repr__',
                                                                                        'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.BaseClient._filter_none_values': ( 'grpc.html#baseclient._filter_none_values',
                                                                                                   'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient': ( 'grpc.html#inferenceclient',
                                                                                    'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient.__init__': ( 'grpc.html#inferenceclient.__init__',
                                                                                             'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient.ping': ( 'grpc.html#inferenceclient.ping',
                                                                                         'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient.predictions': ( 'grpc.html#inferenceclient.predictions',
                                                                                                'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.InferenceClient.stream_predictions': ( 'grpc.html#inferenceclient.stream_predictions',
                                                                                                       'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient': ( 'grpc.html#managementclient',
                                                                                     'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.__init__': ( 'grpc.html#managementclient.__init__',
                                                                                              'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.describe_model': ( 'grpc.html#managementclient.describe_model',
                                                                                                    'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.list_models': ( 'grpc.html#managementclient.list_models',
                                                                                                 'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.register_model': ( 'grpc.html#managementclient.register_model',
                                                                                                    'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.scale_worker': ( 'grpc.html#managementclient.scale_worker',
                                                                                                  'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.set_default': ( 'grpc.html#managementclient.set_default',
                                                                                                 'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.ManagementClient.unregister_model': ( 'grpc.html#managementclient.unregister_model',
                                                                                                      'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.TorchServeClientGRPC': ( 'grpc.html#torchserveclientgrpc',
                                                                                         'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.TorchServeClientGRPC.__init__': ( 'grpc.html#torchserveclientgrpc.__init__',
                                                                                                  'torchserve_client/grpc.py'),
                                        'torchserve_client.grpc.TorchServeClientGRPC.__repr__': ( 'grpc.html#torchserveclientgrpc.__repr__',
                                                                                                  'torchserve_client/grpc.py')},
            'torchserve_client.proto.inference_pb2': {},
            'torchserve_client.proto.inference_pb2_grpc': {},
            'torchserve_client.proto.management_pb2': {},
            'torchserve_client.proto.management_pb2_grpc': {},
            'torchserve_client.rest': { 'torchserve_client.rest.BaseClient': ('rest.html#baseclient', 'torchserve_client/rest.py'),
                                        'torchserve_client.rest.BaseClient.__init__': ( 'rest.html#baseclient.__init__',
                                                                                        'torchserve_client/rest.py'),
                                        'torchserve_client.rest.BaseClient.__repr__': ( 'rest.html#baseclient.__repr__',
                                                                                        'torchserve_client/rest.py'),
                                        'torchserve_client.rest.BaseClient._filter_none_values': ( 'rest.html#baseclient._filter_none_values',
                                                                                                   'torchserve_client/rest.py'),
                                        'torchserve_client.rest.BaseClient._make_request': ( 'rest.html#baseclient._make_request',
                                                                                             'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient': ( 'rest.html#inferenceclient',
                                                                                    'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.__init__': ( 'rest.html#inferenceclient.__init__',
                                                                                             'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.api_description': ( 'rest.html#inferenceclient.api_description',
                                                                                                    'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.explaination': ( 'rest.html#inferenceclient.explaination',
                                                                                                 'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.health_check': ( 'rest.html#inferenceclient.health_check',
                                                                                                 'torchserve_client/rest.py'),
                                        'torchserve_client.rest.InferenceClient.prediction': ( 'rest.html#inferenceclient.prediction',
                                                                                               'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient': ( 'rest.html#managementclient',
                                                                                     'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.__init__': ( 'rest.html#managementclient.__init__',
                                                                                              'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.api_description': ( 'rest.html#managementclient.api_description',
                                                                                                     'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.describe_model': ( 'rest.html#managementclient.describe_model',
                                                                                                    'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.list_models': ( 'rest.html#managementclient.list_models',
                                                                                                 'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.register_model': ( 'rest.html#managementclient.register_model',
                                                                                                    'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.scale_workers': ( 'rest.html#managementclient.scale_workers',
                                                                                                   'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.set_default_version': ( 'rest.html#managementclient.set_default_version',
                                                                                                         'torchserve_client/rest.py'),
                                        'torchserve_client.rest.ManagementClient.unregister_model': ( 'rest.html#managementclient.unregister_model',
                                                                                                      'torchserve_client/rest.py'),
                                        'torchserve_client.rest.TorchServeClientREST': ( 'rest.html#torchserveclientrest',
                                                                                         'torchserve_client/rest.py'),
                                        'torchserve_client.rest.TorchServeClientREST.__init__': ( 'rest.html#torchserveclientrest.__init__',
                                                                                                  'torchserve_client/rest.py'),
                                        'torchserve_client.rest.TorchServeClientREST.__repr__': ( 'rest.html#torchserveclientrest.__repr__',
                                                                                                  'torchserve_client/rest.py')}}}



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: management.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10management.proto\x12!org.pytorch.serve.grpc.management\"!\n\x12ManagementResponse\x12\x0b\n\x03msg\x18\x01 \x01(\t\"U\n\x14\x44\x65scribeModelRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\x12\n\ncustomized\x18\x03 \x01(\x08\";\n\x11ListModelsRequest\x12\r\n\x05limit\x18\x01 \x01(\x05\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\x05\"\xe2\x01\n\x14RegisterModelRequest\x12\x12\n\nbatch_size\x18\x01 \x01(\x05\x12\x0f\n\x07handler\x18\x02 \x01(\t\x12\x17\n\x0finitial_workers\x18\x03 \x01(\x05\x12\x17\n\x0fmax_batch_delay\x18\x04 \x01(\x05\x12\x12\n\nmodel_name\x18\x05 \x01(\t\x12\x18\n\x10response_timeout\x18\x06 \x01(\x05\x12\x0f\n\x07runtime\x18\x07 \x01(\t\x12\x13\n\x0bsynchronous\x18\x08 \x01(\x08\x12\x0b\n\x03url\x18\t \x01(\t\x12\x12\n\ns3_sse_kms\x18\n \x01(\x08\"\xa1\x01\n\x12ScaleWorkerRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\x12\n\nmax_worker\x18\x03 \x01(\x05\x12\x12\n\nmin_worker\x18\x04 \x01(\x05\x12\x12\n\nnumber_gpu\x18\x05 \x01(\x05\x12\x13\n\x0bsynchronous\x18\x06 \x01(\x08\x12\x0f\n\x07timeout\x18\x07 \x01(\x05\">\n\x11SetDefaultRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\"C\n\x16UnregisterModelRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t2\xa0\x06\n\x15ManagementAPIsService\x12\x81\x01\n\rDescribeModel\x12\x37.org.pytorch.serve.grpc.management.DescribeModelRequest\x1a\x35.org.pytorch.serve.grpc.management.ManagementResponse\"\x00\x12{\n\nListModels\x12\x34.org.pytorch.serve.grpc.management.ListModelsRequest\x1a\x35.org.pytorch.serve.grpc.management.ManagementResponse\"\x00\x12\x81\x01\n\rRegisterModel\x12\x37.org.pytorch.serve.grpc.management.RegisterModelRequest\x1a\x35.org.pytorch.serve.grpc.management.ManagementResponse\"\x00\x12}\n\x0bScaleWorker\x12\x35.org.pytorch.serve.grpc.management.ScaleWorkerRequest\x1a\x35.org.pytorch.serve.grpc.management.ManagementResponse\"\x00\x12{\n\nSetDefault\x12\x34.org.pytorch.serve.grpc.management.SetDefaultRequest\x1a\x35.org.pytorch.serve.grpc.management.ManagementResponse\"\x00\x12\x85\x01\n\x0fUnregisterModel\x12\x39.org.pytorch.serve.grpc.management.UnregisterModelRequest\x1a\x35.org.pytorch.serve.grpc.management.ManagementResponse\"\x00\x42\x02P\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'management_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'P\001'
  _MANAGEMENTRESPONSE._serialized_start=55
  _MANAGEMENTRESPONSE._serialized_end=88
  _DESCRIBEMODELREQUEST._serialized_start=90
  _DESCRIBEMODELREQUEST._serialized_end=175
  _LISTMODELSREQUEST._serialized_start=177
  _LISTMODELSREQUEST._serialized_end=236
  _REGISTERMODELREQUEST._serialized_start=239
  _REGISTERMODELREQUEST._serialized_end=465
  _SCALEWORKERREQUEST._serialized_start=468
  _SCALEWORKERREQUEST._serialized_end=629
  _SETDEFAULTREQUEST._serialized_start=631
  _SETDEFAULTREQUEST._serialized_end=693
  _UNREGISTERMODELREQUEST._serialized_start=695
  _UNREGISTERMODELREQUEST._serialized_end=762
  _MANAGEMENTAPISSERVICE._serialized_start=765
  _MANAGEMENTAPISSERVICE._serialized_end=1565
# @@protoc_insertion_point(module_scope)



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_rest.ipynb.

# %% auto 0
__all__ = ['TorchServeClientREST']

# %% ../nbs/01_rest.ipynb 3
import os
import requests

# %% ../nbs/01_rest.ipynb 4
class BaseClient:
    def __init__(self, base_url=None):
        base_url = (
            base_url
            if base_url
            else os.environ.get("TORCHSERVE_URL", "http://localhost")
        )
        self.base_url = base_url.rstrip("/")

    def _make_request(self, method, endpoint, json=None, params=None, files=None):
        """
        json: dict. The JSON body of the request.
        params: dict. The URL parameters of the request.
        files: [dict]. The files to upload.
        """
        url = f"{self.base_url}{endpoint}"
        response = requests.request(method, url, json=json, params=params, files=files)
        response.raise_for_status()
        return response.json()

    def __repr__(self) -> str:
        return f"{self.__class__.__name__}(base_url={self.base_url})"

    def _filter_none_values(self, data):
        return {key: value for key, value in data.items() if value is not None}

# %% ../nbs/01_rest.ipynb 5
class ManagementClient(BaseClient):
    def __init__(self, base_url=None, port=8081):
        super().__init__(base_url)
        self.port = port
        self.base_url = f"{self.base_url}:{self.port}"

    def register_model(
        self,
        url,
        model_name=None,
        handler=None,
        runtime=None,
        batch_size=1,
        max_batch_delay=100,
        initial_workers=0,
        synchronous=False,
        response_timeout=120,
    ):
        data = {
            "url": url,
            "model_name": model_name,
            "handler": handler,
            "runtime": runtime,
            "batch_size": batch_size,
            "max_batch_delay": max_batch_delay,
            "initial_workers": initial_workers,
            "synchronous": synchronous,
            "response_timeout": response_timeout,
        }
        data = self._filter_none_values(data)
        return self._make_request("POST", "/models", json=data)

    def scale_workers(
        self,
        model_name,
        version=None,
        min_worker=1,
        max_worker=None,
        synchronous=False,
        timeout=-1,
    ):
        if version:
            endpoint = f"/models/{model_name}/{version}"
        else:
            endpoint = f"/models/{model_name}"

        params = {
            "min_worker": min_worker,
            "max_worker": max_worker if max_worker is not None else min_worker,
            "synchronous": synchronous,
            "timeout": timeout,
        }

        return self._make_request("PUT", endpoint, json=params)

    def describe_model(self, model_name, version=None, customized=False):
        """
        Returns the model description.
        version :  is optional. if `all` return status of all version of a model. If not provided, the latest version will be returned.
        allowed
        """
        params = {}
        if customized:
            params["customized"] = customized

        if version:
            endpoint = f"/models/{model_name}/{version}"
        else:
            endpoint = f"/models/{model_name}"
        return self._make_request("GET", endpoint, params=params)

    def unregister_model(self, model_name, version=None):
        if version:
            endpoint = f"/models/{model_name}/{version}"
        else:
            endpoint = f"/models/{model_name}"

        return self._make_request("DELETE", endpoint)

    def list_models(self, limit=100, next_page_token=None):
        params = {"limit": limit, "next_page_token": next_page_token}
        params = self._filter_none_values(params)
        return self._make_request("GET", "/models", params=params)

    def api_description(self):
        return self._make_request("OPTIONS", "/")

    def set_default_version(self, model_name, version):
        endpoint = f"/models/{model_name}/{version}/set-default"
        return self._make_request("PUT", endpoint)

# %% ../nbs/01_rest.ipynb 6
class InferenceClient(BaseClient):
    def __init__(self, base_url=None, port=8080):
        super().__init__(base_url)
        self.port = port
        self.base_url = f"{self.base_url}:{self.port}"

    def api_description(self):
        return self._make_request("OPTIONS", "/")

    def health_check(self):
        return self._make_request("GET", "/ping")

    def prediction(self, model_name, data, version=None):
        """
        data = [
            ('data', open('docs/images/dogs-before.jpg', 'rb')),
            ('data', open('docs/images/kitten_small.jpg', 'rb')),
        ]
        """
        if version:
            endpoint = f"/predictions/{model_name}/{version}"
        else:
            endpoint = f"/predictions/{model_name}"

        return self._make_request("POST", endpoint, files=data)

    def explaination(self, model_name, data):
        """
        data <string : bytes>
        """
        endpoint = f"/explanations/{model_name}"
        return self._make_request("POST", endpoint, files=data)

# %% ../nbs/01_rest.ipynb 7
class TorchServeClientREST:
    def __init__(self, base_url=None, management_port=8081, inference_port=8080):
        self.management = ManagementClient(base_url, management_port)
        self.inference = InferenceClient(base_url, inference_port)

    def __repr__(self):
        url = self.management.base_url.rsplit(":", 1)[0]
        return f"TorchServeClientREST(base_url={url}, management_port={self.management.port}, inference_port={self.inference.port})"



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import management_pb2 as management__pb2


class ManagementAPIsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DescribeModel = channel.unary_unary(
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/DescribeModel",
            request_serializer=management__pb2.DescribeModelRequest.SerializeToString,
            response_deserializer=management__pb2.ManagementResponse.FromString,
        )
        self.ListModels = channel.unary_unary(
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/ListModels",
            request_serializer=management__pb2.ListModelsRequest.SerializeToString,
            response_deserializer=management__pb2.ManagementResponse.FromString,
        )
        self.RegisterModel = channel.unary_unary(
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/RegisterModel",
            request_serializer=management__pb2.RegisterModelRequest.SerializeToString,
            response_deserializer=management__pb2.ManagementResponse.FromString,
        )
        self.ScaleWorker = channel.unary_unary(
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/ScaleWorker",
            request_serializer=management__pb2.ScaleWorkerRequest.SerializeToString,
            response_deserializer=management__pb2.ManagementResponse.FromString,
        )
        self.SetDefault = channel.unary_unary(
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/SetDefault",
            request_serializer=management__pb2.SetDefaultRequest.SerializeToString,
            response_deserializer=management__pb2.ManagementResponse.FromString,
        )
        self.UnregisterModel = channel.unary_unary(
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/UnregisterModel",
            request_serializer=management__pb2.UnregisterModelRequest.SerializeToString,
            response_deserializer=management__pb2.ManagementResponse.FromString,
        )


class ManagementAPIsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DescribeModel(self, request, context):
        """Provides detailed information about the default version of a model."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListModels(self, request, context):
        """List registered models in TorchServe."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RegisterModel(self, request, context):
        """Register a new model in TorchServe."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScaleWorker(self, request, context):
        """Configure number of workers for a default version of a model.This is a asynchronous call by default. Caller need to call describeModel to check if the model workers has been changed."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SetDefault(self, request, context):
        """Set default version of a model"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UnregisterModel(self, request, context):
        """Unregister the default version of a model from TorchServe if it is the only version available.This is a asynchronous call by default. Caller can call listModels to confirm model is unregistered"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ManagementAPIsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DescribeModel": grpc.unary_unary_rpc_method_handler(
            servicer.DescribeModel,
            request_deserializer=management__pb2.DescribeModelRequest.FromString,
            response_serializer=management__pb2.ManagementResponse.SerializeToString,
        ),
        "ListModels": grpc.unary_unary_rpc_method_handler(
            servicer.ListModels,
            request_deserializer=management__pb2.ListModelsRequest.FromString,
            response_serializer=management__pb2.ManagementResponse.SerializeToString,
        ),
        "RegisterModel": grpc.unary_unary_rpc_method_handler(
            servicer.RegisterModel,
            request_deserializer=management__pb2.RegisterModelRequest.FromString,
            response_serializer=management__pb2.ManagementResponse.SerializeToString,
        ),
        "ScaleWorker": grpc.unary_unary_rpc_method_handler(
            servicer.ScaleWorker,
            request_deserializer=management__pb2.ScaleWorkerRequest.FromString,
            response_serializer=management__pb2.ManagementResponse.SerializeToString,
        ),
        "SetDefault": grpc.unary_unary_rpc_method_handler(
            servicer.SetDefault,
            request_deserializer=management__pb2.SetDefaultRequest.FromString,
            response_serializer=management__pb2.ManagementResponse.SerializeToString,
        ),
        "UnregisterModel": grpc.unary_unary_rpc_method_handler(
            servicer.UnregisterModel,
            request_deserializer=management__pb2.UnregisterModelRequest.FromString,
            response_serializer=management__pb2.ManagementResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "org.pytorch.serve.grpc.management.ManagementAPIsService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ManagementAPIsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DescribeModel(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/DescribeModel",
            management__pb2.DescribeModelRequest.SerializeToString,
            management__pb2.ManagementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListModels(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/ListModels",
            management__pb2.ListModelsRequest.SerializeToString,
            management__pb2.ManagementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RegisterModel(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/RegisterModel",
            management__pb2.RegisterModelRequest.SerializeToString,
            management__pb2.ManagementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScaleWorker(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/ScaleWorker",
            management__pb2.ScaleWorkerRequest.SerializeToString,
            management__pb2.ManagementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SetDefault(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/SetDefault",
            management__pb2.SetDefaultRequest.SerializeToString,
            management__pb2.ManagementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UnregisterModel(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/org.pytorch.serve.grpc.management.ManagementAPIsService/UnregisterModel",
            management__pb2.UnregisterModelRequest.SerializeToString,
            management__pb2.ManagementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import inference_pb2 as inference__pb2


class InferenceAPIsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
            "/org.pytorch.serve.grpc.inference.InferenceAPIsService/Ping",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=inference__pb2.TorchServeHealthResponse.FromString,
        )
        self.Predictions = channel.unary_unary(
            "/org.pytorch.serve.grpc.inference.InferenceAPIsService/Predictions",
            request_serializer=inference__pb2.PredictionsRequest.SerializeToString,
            response_deserializer=inference__pb2.PredictionResponse.FromString,
        )
        self.StreamPredictions = channel.unary_stream(
            "/org.pytorch.serve.grpc.inference.InferenceAPIsService/StreamPredictions",
            request_serializer=inference__pb2.PredictionsRequest.SerializeToString,
            response_deserializer=inference__pb2.PredictionResponse.FromString,
        )


class InferenceAPIsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ping(self, request, context):
        """Check health status of the TorchServe server."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Predictions(self, request, context):
        """Predictions entry point to get inference using default model version."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StreamPredictions(self, request, context):
        """Streaming response for an inference request."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_InferenceAPIsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Ping": grpc.unary_unary_rpc_method_handler(
            servicer.Ping,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=inference__pb2.TorchServeHealthResponse.SerializeToString,
        ),
        "Predictions": grpc.unary_unary_rpc_method_handler(
            servicer.Predictions,
            request_deserializer=inference__pb2.PredictionsRequest.FromString,
            response_serializer=inference__pb2.PredictionResponse.SerializeToString,
        ),
        "StreamPredictions": grpc.unary_stream_rpc_method_handler(
            servicer.StreamPredictions,
            request_deserializer=inference__pb2.PredictionsRequest.FromString,
            response_serializer=inference__pb2.PredictionResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "org.pytorch.serve.grpc.inference.InferenceAPIsService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class InferenceAPIsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ping(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/org.pytorch.serve.grpc.inference.InferenceAPIsService/Ping",
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            inference__pb2.TorchServeHealthResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Predictions(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/org.pytorch.serve.grpc.inference.InferenceAPIsService/Predictions",
            inference__pb2.PredictionsRequest.SerializeToString,
            inference__pb2.PredictionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StreamPredictions(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/org.pytorch.serve.grpc.inference.InferenceAPIsService/StreamPredictions",
            inference__pb2.PredictionsRequest.SerializeToString,
            inference__pb2.PredictionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



__version__ = "0.0.2"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_init.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/00_init.ipynb 2
from .rest import TorchServeClientREST
from .grpc import TorchServeClientGRPC



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: inference.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0finference.proto\x12 org.pytorch.serve.grpc.inference\x1a\x1bgoogle/protobuf/empty.proto"\xbd\x01\n\x12PredictionsRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12N\n\x05input\x18\x03 \x03(\x0b\x32?.org.pytorch.serve.grpc.inference.PredictionsRequest.InputEntry\x1a,\n\nInputEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01"(\n\x12PredictionResponse\x12\x12\n\nprediction\x18\x01 \x01(\x0c"*\n\x18TorchServeHealthResponse\x12\x0e\n\x06health\x18\x01 \x01(\t2\xf7\x02\n\x14InferenceAPIsService\x12\\\n\x04Ping\x12\x16.google.protobuf.Empty\x1a:.org.pytorch.serve.grpc.inference.TorchServeHealthResponse"\x00\x12{\n\x0bPredictions\x12\x34.org.pytorch.serve.grpc.inference.PredictionsRequest\x1a\x34.org.pytorch.serve.grpc.inference.PredictionResponse"\x00\x12\x83\x01\n\x11StreamPredictions\x12\x34.org.pytorch.serve.grpc.inference.PredictionsRequest\x1a\x34.org.pytorch.serve.grpc.inference.PredictionResponse"\x00\x30\x01\x42\x02P\x01\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "inference_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"P\001"
    _PREDICTIONSREQUEST_INPUTENTRY._options = None
    _PREDICTIONSREQUEST_INPUTENTRY._serialized_options = b"8\001"
    _PREDICTIONSREQUEST._serialized_start = 83
    _PREDICTIONSREQUEST._serialized_end = 272
    _PREDICTIONSREQUEST_INPUTENTRY._serialized_start = 228
    _PREDICTIONSREQUEST_INPUTENTRY._serialized_end = 272
    _PREDICTIONRESPONSE._serialized_start = 274
    _PREDICTIONRESPONSE._serialized_end = 314
    _TORCHSERVEHEALTHRESPONSE._serialized_start = 316
    _TORCHSERVEHEALTHRESPONSE._serialized_end = 358
    _INFERENCEAPISSERVICE._serialized_start = 361
    _INFERENCEAPISSERVICE._serialized_end = 736
# @@protoc_insertion_point(module_scope)
